/**
 * 这是与购物有关的业务逻辑的服务
 */
export default class OrderService {
    constructor(AjaxService) {
        Object.assign(this, { AjaxService })
        this.name = 'OrderService'
    }
    /**
	 *识别收款短信
	 * @param smsContent 短信内容
	 * @param openid 微信openid
    /**/
    orderReceiptReadSms (data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/read/sms', 
            data, 
            isLoading: true ,
            loadText: '识别中...'
              
        })
    }
    /**
	 *获取收款类型
	/**/
    orderReceiptType (data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/type', 
            data, 
            isLoading: true ,
              
        })
    }
    /**
	 *保存收款
	 * @param smsContent 短信内容
	 * @param openid 微信openid
	 * @param payType 付款类型
	 * @param receiptType 收款类型
	 * @param receiptAmount 收款金额
	 * @param handlingFee 手续费
	 * @param receiptDate 收款时间
	/**/
    orderReceiptSave(data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/save', 
            data, 
            isLoading: true ,
            loadText: '保存中...' 
        })
    }
    /**
	 *获取收款列表
	 * @param startDate 筛选开始时间
	 * @param endDate 筛选结束时间
	 * @param openid 微信openid
	 * @param pageNum 页码
	 * @param pageSize 条数
	 * @param receiptStatus 收款状态：0全部 1待确认、2已确认(待审核)、3审核通过、4审核未通过、5收款撤销【线上支付成功为审核通过】
	 * @param receiptType 款项类型：1订单款，2非订单款，3返佣款 4订单款或者非订单款（因财务阶段无法区分订单非订单）, 5供应商退款
	 * @param smsContent 收款短信
	/**/
    orderReceiptList(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/list', 
            data, 
            isLoading: false ,
        })
    }
    /**
	 *获取收款详情
	 * @param id 款项Id
	 * @param openid 微信openid
	/**/
    orderReceiptDetail(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/detail', 
            data, 
            isLoading: true ,
        })
    }
    /**
	 *操作收款信息（作废，设为返佣-普通-供应商退款-非订单款）
	 * @param id 款项Id
	 * @param openid 微信openid
	/**/
    orderReceiptOperate(data = {}) {
        return this.AjaxService.post({ 
            url:'/order/receipt/operate', 
            data, 
            isLoading: true ,
            loadText: '请稍候...' 
        })
    }
    /**
	 *收款详情-订单列表
	 * @param id 收款Id
	 * @param keyword 搜索关键词(客户名称/订单号)
	 * @param orderReceiptStatus 订单收款状态：1待收款(协销待确认款项的订单)，2部分收款（已确认款项的订单），3已收款（已确认款项的订单）
	 * @param organizeId 组织ID
	 * @param pageNum 页码
	 * @param pageSize 条数
	 * @param type 0商品订单(默认)，1订金订单
	/**/
    orderReceiptOrders(data = {}) {
        return this.AjaxService.get({ 
            url:'/order/receipt/detail/orders', 
            data, 
            isLoading: true ,
            loadText: '请稍候...' 
        })
    }
}
